#!/usr/bin/env python3
import matplotlib.pyplot as plt

__all__ = ["ggplot"]

def ggplot():
    """Set my preferred style: The ggplot style"""
    plt.style.use("ggplot")